@@ -540,6 +540,11 @@ class Youtube(SeleniumUploaderAccount):
             time.sleep(1.5)
             self.save_cookies()
 
+            self.__dismiss_welcome_popups(timeout=3)
+            # self.print('__dismiss_dialogs')
+            # self.__dismiss_dialogs(timeout=1)
+            self.__dismiss_callouts(timeout=1)
+
             self._input_file(video_path)
             self.print('Upload: uploaded video')
 
@@ -547,11 +552,9 @@ class Youtube(SeleniumUploaderAccount):
                 self.print(f'Sleeping extra {extra_sleep_after_upload} seconds')
                 time.sleep(extra_sleep_after_upload)
 
-            self.print('__dismiss_welcome_popups')
-            self.__dismiss_welcome_popups(timeout=3)
+            self.__dismiss_welcome_popups(timeout=1)
             # self.print('__dismiss_dialogs')
             # self.__dismiss_dialogs(timeout=1)
-            self.print('__dismiss_callouts')
             self.__dismiss_callouts(timeout=1)
 
             error_dialog = self.browser.find_by('div', class_='error-short style-scope ytcp-uploads-dialog', timeout=10)
@@ -618,12 +621,36 @@ class Youtube(SeleniumUploaderAccount):
             visibility_tab = self.browser.find_by('button', {'test-id':'REVIEW', 'state':'active'})
 
             if not visibility_tab:
-                third_next = self.browser.find_by('ytcp-button', id='next-button')
-                third_next.click()
-                self.print('Upload: clicked third next')
+                for i in range(5):
+                    third_next = self.browser.find_by('ytcp-button', id='next-button', timeout=2)
 
-            visibility_main_button = self.browser.find(By.NAME, visibility.name)
-            self.browser.find(By.ID, 'radioLabel', visibility_main_button).click()
+                    if third_next is not None:
+                        aria_disabled_attr = third_next.get_attribute('aria-disabled')
+                        print(f'third_next: aria-disabled: {aria_disabled_attr} | is_displayed: {third_next.is_displayed()} | is_enabled: {third_next.is_enabled()}')
+
+                        if aria_disabled_attr is not None:
+                            aria_disabled = aria_disabled_attr == 'true' or aria_disabled_attr == True
+
+                            if not aria_disabled:
+                                self.print('Upload: Clicking third next')
+
+                                try:
+                                    third_next.click()
+                                except:
+                                    print('third click not clickable')
+                                    time.sleep(3)
+
+                                    continue
+
+                                self.print('Upload: Clicked third next')
+                                time.sleep(3)
+
+                                break
+
+                    time.sleep(3)
+
+            visibility_main_button = self.browser.find(By.NAME, visibility.name, timeout=5)
+            self.browser.find(By.ID, 'radioLabel', visibility_main_button, timeout=5).click()
             self.print('Upload: set to', visibility.name)
 
             time.sleep(1)
@@ -862,15 +889,19 @@ class Youtube(SeleniumUploaderAccount):
         offset: Tuple[int, int] = (20, 20),
         timeout: Optional[int] = 2
     ) -> bool:
-        element = self.browser.find_by('iron-overlay-backdrop', class_='opened', timeout=timeout)
+        print('__dismiss_welcome_popup')
+        try:
+            element = self.browser.find_by('iron-overlay-backdrop', class_='opened', timeout=timeout)
 
-        if element:
-            return self.browser.move_to_element(
-                element=element,
-                offset=offset,
-                click=True
-            )
-        else:
+            if element:
+                return self.browser.move_to_element(
+                    element=element,
+                    offset=offset,
+                    click=True
+                )
+            else:
+                return False
+        except:
             return False
 
     @noraise(default_return_value=False)
@@ -878,17 +909,24 @@ class Youtube(SeleniumUploaderAccount):
         self,
         timeout: Optional[int] = 2
     ) -> bool:
+        print('__dismiss_welcome_popup_2')
         element = self.browser.find_by('ytcp-warm-welcome-dialog', timeout=timeout)
 
         if not element:
             return False
 
-        close_button = self.browser.find_by('ytcp-button', id_='dismiss-button', timeout=timeout)
+        for i in range(5):
+            close_button = self.browser.find_by('ytcp-button', id_='dismiss-button', timeout=1)
+            print('close_button', close_button)
 
-        if not close_button:
-            return False
+            if close_button is not None:
+                try:
+                    close_button.click()
+                    return False
+                except:
+                    pass
 
-        close_button.click()
+            time.sleep(1)
 
         return True
 
@@ -897,21 +935,25 @@ class Youtube(SeleniumUploaderAccount):
         self,
         timeout: Optional[int] = 2
     ) -> bool:
-        return self.__dismiss_welcome_popup(timeout=timeout) and self.__dismiss_welcome_popup_2(timeout=timeout)
+        return self.__dismiss_welcome_popup_2(timeout=timeout) or self.__dismiss_welcome_popup(timeout=timeout)
 
     @noraise(default_return_value=False)
     def __dismiss_callouts(
         self,
         timeout: Optional[int] = 2
     ) -> None:
+        print('__dismiss_callouts')
         element = self.browser.find_by('div', id='callout', role='dialog', timeout=timeout)
 
         while element is not None:
-            close_button = self.browser.find_by('ytcp-button', id='close-button', role='dialog' ,in_element=element, timeout=timeout)
+            print('dismissing callount')
+            close_button = self.browser.find_by('ytcp-button', id='close-button', in_element=element, timeout=timeout)
 
             if close_button:
                 close_button.click()
                 time.sleep(4)
+            else:
+                break
 
             element = self.browser.find_by('div', id='callout', role='dialog', timeout=timeout)
 
@@ -928,6 +970,8 @@ class Youtube(SeleniumUploaderAccount):
             if close_button:
                 close_button.click()
                 time.sleep(4)
+            else:
+                break
 
             element = self.browser.find_by('ytcp-dialog', timeout=timeout)
 
